==> kubernetes-model-1.0.59-sources.jar: io/fabric8/openshift/api/model/TagImageHookBuilder.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
import javax.validation.Validation;
import javax.validation.Validator;
import javax.validation.ValidatorFactory;
import javax.validation.ValidationException;
import javax.validation.ConstraintViolation;
import javax.validation.ConstraintViolationException;
import java.util.Set;
import java.lang.Object;

public class TagImageHookBuilder extends TagImageHookFluentImpl<TagImageHookBuilder> implements VisitableBuilder<TagImageHook,TagImageHookBuilder>{

    TagImageHookFluent<?> fluent;
    Boolean validationEnabled;

    public TagImageHookBuilder(){
            this(true);
    }
    public TagImageHookBuilder(Boolean validationEnabled){
            this(new TagImageHook(), validationEnabled);
    }
    public TagImageHookBuilder(TagImageHookFluent<?> fluent){
            this(fluent, true);
    }
    public TagImageHookBuilder(TagImageHookFluent<?> fluent,Boolean validationEnabled){
            this(fluent, new TagImageHook(), validationEnabled);
    }
    public TagImageHookBuilder(TagImageHookFluent<?> fluent,TagImageHook instance){
            this(fluent, instance, true);
    }
    public TagImageHookBuilder(TagImageHookFluent<?> fluent,TagImageHook instance,Boolean validationEnabled){
            this.fluent = fluent; 
            fluent.withContainerName(instance.getContainerName()); 
            fluent.withTo(instance.getTo()); 
            this.validationEnabled = validationEnabled; 
    }
    public TagImageHookBuilder(TagImageHook instance){
            this(instance,true);
    }
    public TagImageHookBuilder(TagImageHook instance,Boolean validationEnabled){
            this.fluent = this; 
            this.withContainerName(instance.getContainerName()); 
            this.withTo(instance.getTo()); 
            this.validationEnabled = validationEnabled; 
    }

    public TagImageHook build(){
            TagImageHook buildable = new TagImageHook(fluent.getContainerName(),fluent.getTo());
            validate(buildable);
            return buildable;
    }

    private <T>void validate(T item){
            if (!validationEnabled) { return; }
            Validator validator = null;
            try {
                ValidatorFactory factory = Validation.buildDefaultValidatorFactory();
                validator = factory.getValidator();
            } catch(ValidationException e) {return;}
            Set<ConstraintViolation<T>> violations = validator.validate(item);
            if (!violations.isEmpty()) {
            throw new ConstraintViolationException(violations);
             }
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            TagImageHookBuilder that = (TagImageHookBuilder) o;
            if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

            if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
            return true;
    }




}

==> kubernetes-model-1.0.60-sources.jar: io/fabric8/openshift/api/model/TagImageHookBuilder.java <==
package io.fabric8.openshift.api.model;

import javax.validation.Validation;
import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.util.Set;
import javax.annotation.Generated;
import javax.validation.ValidationException;
import javax.validation.ValidatorFactory;
import lombok.EqualsAndHashCode;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.databind.annotation.JsonDeserialize;
import javax.validation.ConstraintViolation;
import javax.validation.ConstraintViolationException;
import java.lang.Object;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import java.lang.Boolean;
import lombok.ToString;
import io.sundr.builder.annotations.Buildable;
import javax.validation.Validator;

public class TagImageHookBuilder extends TagImageHookFluentImpl<TagImageHookBuilder> implements VisitableBuilder<TagImageHook,TagImageHookBuilder>{

    TagImageHookFluent<?> fluent;
    Boolean validationEnabled;

    public TagImageHookBuilder(){
            this(true);
    }
    public TagImageHookBuilder(Boolean validationEnabled){
            this(new TagImageHook(), validationEnabled);
    }
    public TagImageHookBuilder(TagImageHookFluent<?> fluent){
            this(fluent, true);
    }
    public TagImageHookBuilder(TagImageHookFluent<?> fluent,Boolean validationEnabled){
            this(fluent, new TagImageHook(), validationEnabled);
    }
    public TagImageHookBuilder(TagImageHookFluent<?> fluent,TagImageHook instance){
            this(fluent, instance, true);
    }
    public TagImageHookBuilder(TagImageHookFluent<?> fluent,TagImageHook instance,Boolean validationEnabled){
            this.fluent = fluent; 
            fluent.withContainerName(instance.getContainerName()); 
            fluent.withTo(instance.getTo()); 
            this.validationEnabled = validationEnabled; 
    }
    public TagImageHookBuilder(TagImageHook instance){
            this(instance,true);
    }
    public TagImageHookBuilder(TagImageHook instance,Boolean validationEnabled){
            this.fluent = this; 
            this.withContainerName(instance.getContainerName()); 
            this.withTo(instance.getTo()); 
            this.validationEnabled = validationEnabled; 
    }

    public TagImageHook build(){
            TagImageHook buildable = new TagImageHook(fluent.getContainerName(),fluent.getTo());
            validate(buildable);
            return buildable;
    }

    private <T>void validate(T item){
            if (!validationEnabled) { return; }
            Validator validator = null;
            try {
                ValidatorFactory factory = Validation.buildDefaultValidatorFactory();
                validator = factory.getValidator();
            } catch(ValidationException e) {return;}
            Set<ConstraintViolation<T>> violations = validator.validate(item);
            if (!violations.isEmpty()) {
            throw new ConstraintViolationException(violations);
             }
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            TagImageHookBuilder that = (TagImageHookBuilder) o;
            if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

            if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
            return true;
    }




}
